from fastapi import APIRouter, Depends, Query
from sqlmodel import Session

from parsomics_core.entities.omics.repeated_region import (
    RepeatedRegion,
    RepeatedRegionPublic,
    RepeatedRegionTransactions,
)

from parsomics_api_server.dependencies import get_session_ro
from parsomics_api_server.entities._helpers import RoutingHelpers


_routing_helpers = RoutingHelpers(
    table_type=RepeatedRegion,
    transactions=RepeatedRegionTransactions(),
)
router = APIRouter(
    prefix="/repeated_region",
    tags=["omics/repeated_region"],
    responses={
        404: {"description": "Not found"},
        500: {"description": "Internal server error"},
    },
)


@router.get("/item/{key}", response_model=RepeatedRegionPublic)
def get_repeated_region(
    *,
    session: Session = Depends(get_session_ro),
    key: int,
):
    return _routing_helpers.get(session, key)


@router.post("/items/", response_model=list[RepeatedRegionPublic])
def get_repeated_regions(
    *,
    session: Session = Depends(get_session_ro),
    keys: list[int],
):
    return _routing_helpers.get_batch(session, keys)


@router.get("/", response_model=list[RepeatedRegionPublic])
def read_repeated_regions(
    *,
    session: Session = Depends(get_session_ro),
    offset: int = 0,
    limit: int = Query(default=100, le=100),
):
    return _routing_helpers.read(session, offset, limit)
